/**
 * @file SPEECH_COMMANDS.h
 * @author Corey McCall (corey.mccall@femtosense.ai)
 * @brief
 * @version 2.0
 * @date 2024-03-21
 *
 * @copyright Copyright (c) 2024
 *
 */
#ifndef SPEECHCOMMANDS_H
#define SPEECHCOMMANDS_H

//Audio parameters (set at compile time):
#define SAMPLE_RATE_HZ 8000                //audio sample rate 
#define HOP_SIZE 128                       //audio buffer length to process (value is number of samples)

//IO pins:
#define LED_GREEN 15                       //EVK green LED
#define LED_RED 16                         //EVK red LED
#define BUTTON_SW1 25                      //EVK button 1 (AI on/off)
#define BUTTON_SW2 29                      //EVK button 2 (currently unused)
#define PSU_PIN 31                         //SPU 0.8V regulator enable
#define SPU_RESET_PIN 32                   //SPU reset signal
#define SPU_INT_OR_REFCLK 6                //SPU interrupt or reference clock (depending on jumper configuration)
#define SS_FLASH 24                        //Flash chip SS on the SPU EVK board
#define SS_SPU SS                          //SPU chip SS on the SPU EVK board

//Other firmware parameters:
extern int PRINT_EXECUTION_TIME;
extern int CONFIRM_2MIC;  
    
//Power tuning parameters:
extern int VCO_MHZ;            
extern int CLKOD;              
extern int USE_MEMORY_FSM;     
extern int DISABLE_CORE1;

//Power tuning parameters (TC2 only):
extern int CORE_GATING_EN;                
extern unsigned int CORE0_READY_US;       
extern unsigned int CORE_TRANSFER_US;      
extern unsigned int SAFETY_MARGIN_US;      
extern unsigned int TOTAL_WAIT_TIME_US;    

//Other SPU parameters:
extern uint32_t SPI_SPEED;         
extern int USE_ONBOARD_XTAL;                        
extern int USE_INT_PIN;   

//calculated parameters
extern int CLKOD_IO;

//ML model parameters
extern int NUMBER_OF_COMMANDS;

#endif